@@ -16,6 +16,8 @@ from pygments.formatters.html import HtmlFormatter
 from pygments.lexers.data import JsonLexer
 import logging
 
+from blog.managers import DefaultEntriesManager, DefaultCommentManager
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
@@ -86,6 +88,8 @@ class EntryEnvelope(models.Model):
 
     defunct = models.BooleanField(null=False, default=False)
 
+    objects = DefaultEntriesManager()
+
     def entry_formatted(self):
         # dump the json with indentation set
 
@@ -164,6 +168,10 @@ class Comment(models.Model):
     modified_on = models.DateTimeField(auto_now_add=True)
     content = models.TextField(null=False)
 
+    approved = models.BooleanField(null=False, default=False)
+
+    objects = DefaultCommentManager()
+
 
 class View(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
