@@ -22,6 +22,19 @@ class IsOwnerOrReadOnly(permissions.BasePermission):
         # Write permissions are only allowed to the owner of the snippet.
         return obj.author == request.user
 
+class ReadOnly(permissions.BasePermission):
+    """
+    Custom permission to only allow owners of an object to edit it.
+    """
+
+    def has_object_permission(self, request, view, obj):
+        # Read permissions are allowed to any request,
+        # so we'll always allow GET, HEAD or OPTIONS requests.
+        if request.method in permissions.SAFE_METHODS:
+            return True
+        else:
+            return False
+
 
 class IsUserOrReadOnly(permissions.BasePermission):
     def has_object_permission(self, request, view, obj):
@@ -30,6 +43,13 @@ class IsUserOrReadOnly(permissions.BasePermission):
         return obj.user == request.user
 
 
+class CanApprove(permissions.BasePermission):
+    def has_object_permission(self, request, view, obj):
+        if request.method in permissions.SAFE_METHODS:
+            return True
+        return obj.entry_envelope.author == request.user
+
+
 class InOrganization(permissions.BasePermission):
     def has_object_permission(self, request, view, obj):
         user = request.user
